using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;

namespace GaugeClock
{
	public partial class GaugeClockViewController : UIViewController
	{
		public GaugeClockViewController () : base ("GaugeClockViewController", null)
		{
		}

		IGGaugeClock1 _clock;

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			this.View.BackgroundColor = UIColor.White;

			_clock = new IGGaugeClock1 ();
			_clock.Frame = new RectangleF (0, 0, this.View.Frame.Size.Width, this.View.Frame.Size.Height);
			_clock.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
			this.View.AddSubview (_clock);
		}

	}


	public class IGGaugeClock1 :UIView
	{
		IGGaugeView _backgroundGauge;
		IGGaugeView _hoursGauge;
		UIImageView  _imageView, _glassImage;

		public IGGaugeClock1():base()
		{
			this.Setup ();
		}

		public string ImageName
		{
			get {
				return @"Clock2.png";
			}
		}

		public void Setup()
		{
			if(_hoursGauge == null)
			{
				_imageView = new UIImageView (new RectangleF(0,0,this.Frame.Size.Width, this.Frame.Size.Height));
				_imageView.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
				_imageView.ContentMode = UIViewContentMode.ScaleAspectFit;
				_imageView.Image = UIImage.FromBundle (this.ImageName);
				this.AddSubview (_imageView);


				// Initialize all Gauges with the same exact frame
				_hoursGauge = new IGGaugeView ();
				_hoursGauge.Frame = new RectangleF(0,0,this.Frame.Size.Width, this.Frame.Size.Height);
				_hoursGauge.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
				_backgroundGauge = new IGGaugeView ();
				_backgroundGauge.Frame = new RectangleF(0,0,this.Frame.Size.Width, this.Frame.Size.Height);
				_backgroundGauge.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;


				// Add all of our subviews to the visual tree
				this.AddSubview (_backgroundGauge);
				this.AddSubview (_hoursGauge);
			
				// Hide the 0 label
				_backgroundGauge.DuplicateLabelOmissionStrategy = IGGaugeDuplicateLabelOmissionStrategy.IGGaugeDuplicateLabelOmissionStrategyOmitFirst;

				// Hide the other gauge labels
				_hoursGauge.Font = UIFont.SystemFontOfSize (1);

				_backgroundGauge.NeedlePivotShape = IGGaugePivotShape.IGGaugePivotShapeNone;

				// Hide elements from our top level gauges by setting the brush color to clear
				_backgroundGauge.NeedleOutline = _hoursGauge.MinorTickBrush = _hoursGauge.TickBrush = _backgroundGauge.ScaleBrush = _hoursGauge.BackingBrush = _backgroundGauge.NeedleBrush = _hoursGauge.ScaleBrush = _hoursGauge.BackingOutline = new IGBrush (UIColor.Clear);

				_hoursGauge.BackingStrokeThickness = 0; 

				// Set the Start and End Angles of the scale - All gauges must have the same values
				_backgroundGauge.ScaleStartAngle = _hoursGauge.ScaleStartAngle =  270;
				_backgroundGauge.ScaleEndAngle = _hoursGauge.ScaleEndAngle = 270 + 360;

				// Since we don't want to see the major tick marks, lets set the internval to a larger number to limit how many tick marks try to render.
				_hoursGauge.Interval =  60;

				// Set the Max Values
				_backgroundGauge.MaximumValue = _hoursGauge.MaximumValue = 12;

				// Since we don't want to see these tick marks, lets set the minor tick marks count to zero so no tick marks try to render.
				_hoursGauge.MinorTickCount = 0;

				// Setup the Tick marks for the background
				_backgroundGauge.Interval = 1;
				_backgroundGauge.MinorTickCount = 4;

				this.SetupStyling ();

				_hoursGauge.Value = 60;
			}
		}

		public override RectangleF Frame {
			get {
				return base.Frame;
			}
			set 
			{
				base.Frame = value;

				if (this._backgroundGauge == null)
					return;


			
				float val = .11f;


				if(this.Frame.Size.Height > this.Frame.Size.Width)
				{
				
					val = .09f;
				}
				_backgroundGauge.CenterY = _hoursGauge.CenterY = .50f + val;
			}
		}

		public void SetupStyling()
		{
			_glassImage = new UIImageView (new RectangleF(0,0,this.Frame.Size.Width, this.Frame.Size.Height));
			_glassImage.AutoresizingMask = UIViewAutoresizing.FlexibleWidth | UIViewAutoresizing.FlexibleHeight;
			_glassImage.ContentMode = UIViewContentMode.ScaleAspectFit;
			_glassImage.Image = UIImage.FromBundle (@"Clock2Shadow.png");
			this.AddSubview (_glassImage);

			bool iPhone = false;//[igNavController iPhone];

			// Make the Number labels render inside of the tickmarks as opposed to outside of them
			_backgroundGauge.LabelExtent = .50f;

			// Move the TickMarks further out from the center of the clock
			_backgroundGauge.TickStartExtent = .59f;
			_backgroundGauge.TickEndExtent = .64f;
			_backgroundGauge.MinorTickStartExtent = .59f;
			_backgroundGauge.MinorTickEndExtent =  .64f;

			_backgroundGauge.MaximumValue = 60f;
			_backgroundGauge.Interval = 5f;

		
			// Set the font for our labels
			_backgroundGauge.Font = UIFont.FromName (@"Verdana", (iPhone) ? 20f : 40f);

			// Move the Backing out and set its colors and stroke thickness
			_backgroundGauge.BackingOuterExtent = .93f;
			_backgroundGauge.BackingStrokeThickness = 0f;
			_backgroundGauge.BackingOutline = _backgroundGauge.BackingBrush = new IGBrush(UIColor.Clear);

			// Make the hours hand smaller
			_hoursGauge.NeedleEndExtent = .6f;
			_hoursGauge.NeedlePointFeatureExtent = .55f;

		
			// Change the thickness of the minutes and hours hands.
			_hoursGauge.NeedleStartWidthRatio = .03f;
			_hoursGauge.NeedleEndWidthRatio = .03f;
			_hoursGauge.NeedlePointFeatureWidthRatio = .02f;

			_hoursGauge.NeedlePivotWidthRatio =  .001f;



			_hoursGauge.NeedlePivotBrush = new IGBrush(UIColor.Black);
			_hoursGauge.NeedlePivotOutline = new IGBrush(UIColor.White);


			_hoursGauge.NeedleShape = IGGaugeNeedleShape.IGGaugeNeedleShapeTriangle;

			_hoursGauge.NeedlePivotShape =  IGGaugePivotShape.IGGaugePivotShapeCircleUnderlayWithHole;

			IGGaugeRange range = new IGGaugeRange ();
			range.Outline = new IGBrush (UIColor.Black);
			range.StrokeThickness = 2;
			range.StartValue = 0;
			range.EndValue = 60;
			range.InnerStartExtent = .59f;
			range.InnerEndExtent = .59f;
			range.OuterEndExtent = .59f;
			range.OuterStartExtent = .59f;
			_backgroundGauge.AddRange (range);



			this.Frame = this.Frame;
		
		}

	}
}

